.. image:: https://img.shields.io/pypi/v/tempora.svg
   :target: https://pypi.org/project/tempora

.. image:: https://img.shields.io/pypi/pyversions/tempora.svg

.. image:: https://github.com/jaraco/tempora/actions/workflows/main.yml/badge.svg
   :target: https://github.com/jaraco/tempora/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json
    :target: https://github.com/astral-sh/ruff
    :alt: Ruff

.. image:: https://readthedocs.org/projects/tempora/badge/?version=latest
   :target: https://tempora.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2024-informational
   :target: https://blog.jaraco.com/skeleton

.. image:: https://tidelift.com/badges/package/pypi/tempora
   :target: https://tidelift.com/subscription/pkg/pypi-tempora?utm_source=pypi-tempora&utm_medium=readme

Objects and routines pertaining to date and time (tempora).

Modules include:

- tempora (top level package module) contains miscellaneous
   utilities and constants.
- timing contains routines for measuring and profiling.
- schedule contains an event scheduler.
- utc contains routines for getting datetime-aware UTC values.

For Enterprise
==============

Available as part of the Tidelift Subscription.

This project and the maintainers of thousands of other packages are working with Tidelift to deliver one enterprise subscription that covers all of the open source you use.

`Learn more <https://tidelift.com/subscription/pkg/pypi-tempora?utm_source=pypi-tempora&utm_medium=referral&utm_campaign=github>`_.
